@@ -149,6 +149,9 @@ if (!array_key_exists($page, $allowed_pages)) {
                     <a href="index.php?page=wordpress" class="list-group-item list-group-item-action py-3 <?php echo $page === 'wordpress' ? 'active' : ''; ?>">
                         <i class="fa fa-wordpress me-3"></i>WordPress Management
                     </a>
+                    <a href="index.php?page=cpanel-import" class="list-group-item list-group-item-action py-3 <?php echo $page === 'cpanel-import' ? 'active' : ''; ?>">
+                        <i class="fa fa-upload me-3"></i>cPanel Import
+                    </a>
                     <?php if (defined('AUTH_USER') && AUTH_USER === 'root'): ?>
                     <a href="index.php?page=user-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'user-management' ? 'active' : ''; ?>">
                         <i class="fa fa-users me-3"></i>User Management
