@@ -301,6 +301,10 @@ function startReleaseUpdate() {
                             if (data.error) {
                                 appendOutput(`ERROR: ${data.error}`);
                             }
+                            if (data.heartbeat) {
+                                // Just keep connection alive, don't display heartbeat
+                                console.log('Heartbeat received');
+                            }
                         } catch (e) {
                             // If not JSON, treat as plain text
                             appendOutput(line);
@@ -362,6 +366,10 @@ function startPackageUpdate() {
                             if (data.error) {
                                 appendOutput(`ERROR: ${data.error}`);
                             }
+                            if (data.heartbeat) {
+                                // Just keep connection alive, don't display heartbeat
+                                console.log('Heartbeat received');
+                            }
                         } catch (e) {
                             // If not JSON, treat as plain text
                             appendOutput(line);
