@@ -100,18 +100,10 @@ function whp_CreateAccount(array $params) {
     try {
         $serverdata = whp_getServerData($params);
         
-        // Enhanced debugging for CreateAccount
-        logModuleCall('whp', 'CreateAccount_Debug', array(
-            'params_keys' => array_keys($params),
-            'serverdata_extracted' => array(
-                'hostname' => $serverdata['hostname'] ?? 'not set',
-                'username' => !empty($serverdata['username']) ? 'set' : 'empty',
-                'password' => !empty($serverdata['password']) ? 'set' : 'empty'
-            )
-        ), 'CreateAccount parameter debugging');
         
         $username = $params['username'];
         $password = $params['password'];
+        $domain = $params['domain'] ?? '';
         $configoptions = $params['configoptions'];
         
         // Prepare API request
@@ -127,6 +119,11 @@ function whp_CreateAccount(array $params) {
             ),
         );
         
+        // Add domain if provided
+        if (!empty($domain)) {
+            $apiData['domain'] = $domain;
+        }
+        
         // Make API call to create user
         $response = whp_api_call($serverdata, 'POST', 'users.php?action=create', $apiData);
         
